.. -*- mode: rst -*-

|Travis|_ |Codecov|_ |CircleCI|_ |ReadTheDocs|_

.. |Travis| image:: https://travis-ci.com/Mind-the-Pineapple/sklearn-rvm.svg?branch=master
.. _Travis: https://travis-ci.com/Mind-the-Pineapple/sklearn-rvm

.. |Codecov| image:: https://codecov.io/gh/Mind-the-Pineapple/sklearn-rvm/branch/master/graph/badge.svg
.. _Codecov: https://codecov.io/gh/Mind-the-Pineapple/sklearn-rvm

.. |CircleCI| image:: https://circleci.com/gh/Mind-the-Pineapple/sklearn-rvm.svg?style=shield&circle-token=:circle-token
.. _CircleCI: https://circleci.com/gh/Mind-the-Pineapple/sklearn-rvm

.. |ReadTheDocs| image:: https://readthedocs.org/projects/sklearn-rvm/badge/?version=latest
.. _ReadTheDocs: https://sklearn-rvm.readthedocs.io/en/latest/?badge=latest

Sklearn-RVM
===========


Installation
------------

.. code:: bash

    pip install sklearn-rvm


Requirements
------------
.. _Scikit-Learn: https://scikit-learn.org/

- Python (>= 3.5)
- Scikit-Learn_ (>= 0.21)

Documentation
-------------

.. _documentation: https://sklearn-rvm.readthedocs.io/en/latest/index.html

Refer to the documentation_ to modify the template for your own scikit-learn
contribution.